@@ -89,7 +89,7 @@ interface IElementAttrs extends IVNodeAttrs {
   onmouseout?: (ev: MouseEvent) => any;
   onmouseover?: (ev: MouseEvent) => any;
   onmouseup?: (ev: MouseEvent) => any;
-  onmousewheel?: (ev: MouseWheelEvent) => any;
+  onmousewheel?: (ev: WheelEvent) => any;
   onpaste?: (ev: DragEvent) => any;
   onpause?: (ev: Event) => any;
   onplay?: (ev: Event) => any;
